package Perinci::CmdLine::dux::I18N;
use parent 'Perinci::CmdLine::I18N';

our $VERSION = '1.20'; # VERSION

1;
# ABSTRACT: Project class for Perinci::CmdLine::dux

__END__
=pod

=head1 NAME

Perinci::CmdLine::dux::I18N - Project class for Perinci::CmdLine::dux

=head1 VERSION

version 1.20

=head1 DESCRIPTION


This module has L<Rinci> metadata.

=head1 FUNCTIONS


None are exported by default, but they are exportable.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

