package Data::Unixish::Implementation;

# empty module, to avoid dzil or someone else complaining

our $VERSION = '1.20'; # VERSION

1;
# ABSTRACT: Data::Unixish

__END__
=pod

=head1 NAME

Data::Unixish::Implementation - Data::Unixish

=head1 VERSION

version 1.20

=head1 DESCRIPTION


This module has L<Rinci> metadata.

=head1 FUNCTIONS


None are exported by default, but they are exportable.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

